@@ -91,8 +91,8 @@ class Client:
             raise exceptions.CakeworkError("Error happened while getting status") from err
         if response is not None:
             if response.status_code == 200:
-                status = response.json()
-                return json.dumps(status)
+                status = response.text
+                return json.loads(status)
             elif response.status_code == 404:
                 return None
             else:
@@ -121,8 +121,8 @@ class Client:
             raise exceptions.CakeworkError("Something unexpected happened")
         if response is not None:
             if response.status_code == 200:
-                result = response.json()
-                return json.loads(result)
+                result = json.loads(response.json())
+                return result
             elif response.status_code == 404:
                 return None
             else:
